@@ -3,6 +3,7 @@ package artifact
 import (
 	"context"
 	"errors"
+	"fmt"
 	"os"
 
 	"github.com/hashicorp/go-multierror"
@@ -19,7 +20,9 @@ import (
 	tcache "github.com/aquasecurity/trivy/pkg/cache"
 	"github.com/aquasecurity/trivy/pkg/commands/operation"
 	"github.com/aquasecurity/trivy/pkg/log"
+	"github.com/aquasecurity/trivy/pkg/module"
 	pkgReport "github.com/aquasecurity/trivy/pkg/report"
+	"github.com/aquasecurity/trivy/pkg/result"
 	"github.com/aquasecurity/trivy/pkg/rpc/client"
 	"github.com/aquasecurity/trivy/pkg/scanner"
 	"github.com/aquasecurity/trivy/pkg/types"
@@ -63,24 +66,44 @@ type ScannerConfig struct {
 	ArtifactOption artifact.Option
 }
 
-type Runner struct {
-	cache  cache.Cache
-	dbOpen bool
+type Runner interface {
+	// ScanImage scans an image
+	ScanImage(ctx context.Context, opt Option) (types.Report, error)
+	// ScanFilesystem scans a filesystem
+	ScanFilesystem(ctx context.Context, opt Option) (types.Report, error)
+	// ScanRootfs scans rootfs
+	ScanRootfs(ctx context.Context, opt Option) (types.Report, error)
+	// ScanRepository scans repository
+	ScanRepository(ctx context.Context, opt Option) (types.Report, error)
+	// Filter filter a report
+	Filter(ctx context.Context, opt Option, report types.Report) (types.Report, error)
+	// Report a writes a report
+	Report(opt Option, report types.Report) error
+	// Close closes runner
+	Close(ctx context.Context) error
 }
 
-type runnerOption func(*Runner)
+type runner struct {
+	cache  cache.Cache
+	dbOpen bool
+
+	// WASM modules
+	module *module.Manager
+}
+
+type runnerOption func(*runner)
 
 // WithCacheClient takes a custom cache implementation
 func WithCacheClient(c cache.Cache) runnerOption {
-	return func(r *Runner) {
+	return func(r *runner) {
 		r.cache = c
 	}
 }
 
 // NewRunner initializes Runner that provides scanning functionalities.
 // It is possible to return SkipScan and it must be handled by caller.
-func NewRunner(cliOption Option, opts ...runnerOption) (*Runner, error) {
-	r := &Runner{}
+func NewRunner(cliOption Option, opts ...runnerOption) (Runner, error) {
+	r := &runner{}
 	for _, opt := range opts {
 		opt(r)
 	}
@@ -98,11 +121,19 @@ func NewRunner(cliOption Option, opts ...runnerOption) (*Runner, error) {
 		return nil, xerrors.Errorf("DB error: %w", err)
 	}
 
+	// Initialize WASM modules
+	m, err := module.NewManager(cliOption.Context.Context)
+	if err != nil {
+		return nil, xerrors.Errorf("WASM module error: %w", err)
+	}
+	m.Register()
+	r.module = m
+
 	return r, nil
 }
 
 // Close closes everything
-func (r *Runner) Close() error {
+func (r *runner) Close(ctx context.Context) error {
 	var errs error
 	if err := r.cache.Close(); err != nil {
 		errs = multierror.Append(errs, err)
@@ -113,10 +144,14 @@ func (r *Runner) Close() error {
 			errs = multierror.Append(errs, err)
 		}
 	}
+
+	if err := r.module.Close(ctx); err != nil {
+		errs = multierror.Append(errs, err)
+	}
 	return errs
 }
 
-func (r *Runner) ScanImage(ctx context.Context, opt Option) (types.Report, error) {
+func (r *runner) ScanImage(ctx context.Context, opt Option) (types.Report, error) {
 	// Disable the lock file scanning
 	opt.DisabledAnalyzers = analyzer.TypeLockfiles
 
@@ -136,24 +171,24 @@ func (r *Runner) ScanImage(ctx context.Context, opt Option) (types.Report, error
 		s = imageRemoteScanner
 	}
 
-	return r.Scan(ctx, opt, s)
+	return r.scanArtifact(ctx, opt, s)
 }
 
-func (r *Runner) ScanFilesystem(ctx context.Context, opt Option) (types.Report, error) {
+func (r *runner) ScanFilesystem(ctx context.Context, opt Option) (types.Report, error) {
 	// Disable the individual package scanning
 	opt.DisabledAnalyzers = append(opt.DisabledAnalyzers, analyzer.TypeIndividualPkgs...)
 
 	return r.scanFS(ctx, opt)
 }
 
-func (r *Runner) ScanRootfs(ctx context.Context, opt Option) (types.Report, error) {
+func (r *runner) ScanRootfs(ctx context.Context, opt Option) (types.Report, error) {
 	// Disable the lock file scanning
 	opt.DisabledAnalyzers = append(opt.DisabledAnalyzers, analyzer.TypeLockfiles...)
 
 	return r.scanFS(ctx, opt)
 }
 
-func (r *Runner) scanFS(ctx context.Context, opt Option) (types.Report, error) {
+func (r *runner) scanFS(ctx context.Context, opt Option) (types.Report, error) {
 	var s InitializeScanner
 	if opt.RemoteAddr == "" {
 		// Scan filesystem in standalone mode
@@ -163,20 +198,20 @@ func (r *Runner) scanFS(ctx context.Context, opt Option) (types.Report, error) {
 		s = filesystemRemoteScanner
 	}
 
-	return r.Scan(ctx, opt, s)
+	return r.scanArtifact(ctx, opt, s)
 }
 
-func (r *Runner) ScanRepository(ctx context.Context, opt Option) (types.Report, error) {
+func (r *runner) ScanRepository(ctx context.Context, opt Option) (types.Report, error) {
 	// Do not scan OS packages
 	opt.VulnType = []string{types.VulnTypeLibrary}
 
 	// Disable the OS analyzers and individual package analyzers
 	opt.DisabledAnalyzers = append(analyzer.TypeIndividualPkgs, analyzer.TypeOSes...)
 
-	return r.Scan(ctx, opt, repositoryStandaloneScanner)
+	return r.scanArtifact(ctx, opt, repositoryStandaloneScanner)
 }
 
-func (r *Runner) Scan(ctx context.Context, opt Option, initializeScanner InitializeScanner) (types.Report, error) {
+func (r *runner) scanArtifact(ctx context.Context, opt Option, initializeScanner InitializeScanner) (types.Report, error) {
 	report, err := scan(ctx, opt, initializeScanner, r.cache)
 	if err != nil {
 		return types.Report{}, xerrors.Errorf("scan error: %w", err)
@@ -185,15 +220,12 @@ func (r *Runner) Scan(ctx context.Context, opt Option, initializeScanner Initial
 	return report, nil
 }
 
-func (r *Runner) Filter(ctx context.Context, opt Option, report types.Report) (types.Report, error) {
-	resultClient := initializeResultClient()
+func (r *runner) Filter(ctx context.Context, opt Option, report types.Report) (types.Report, error) {
 	results := report.Results
+
+	// Filter results
 	for i := range results {
-		// Fill vulnerability info only in standalone mode
-		if opt.RemoteAddr == "" {
-			resultClient.FillVulnerabilityInfo(results[i].Vulnerabilities, results[i].Type)
-		}
-		vulns, misconfSummary, misconfs, secrets, err := resultClient.Filter(ctx, results[i].Vulnerabilities, results[i].Misconfigurations, results[i].Secrets,
+		vulns, misconfSummary, misconfs, secrets, err := result.Filter(ctx, results[i].Vulnerabilities, results[i].Misconfigurations, results[i].Secrets,
 			opt.Severities, opt.IgnoreUnfixed, opt.IncludeNonFailures, opt.IgnoreFile, opt.IgnorePolicy)
 		if err != nil {
 			return types.Report{}, xerrors.Errorf("unable to filter vulnerabilities: %w", err)
@@ -206,11 +238,12 @@ func (r *Runner) Filter(ctx context.Context, opt Option, report types.Report) (t
 	return report, nil
 }
 
-func (r *Runner) Report(opt Option, report types.Report) error {
+func (r *runner) Report(opt Option, report types.Report) error {
 	if err := pkgReport.Write(report, pkgReport.Option{
 		AppVersion:         opt.GlobalOption.AppVersion,
 		Format:             opt.Format,
 		Output:             opt.Output,
+		Tree:               opt.DependencyTree,
 		Severities:         opt.Severities,
 		OutputTemplate:     opt.Template,
 		IncludeNonFailures: opt.IncludeNonFailures,
@@ -222,7 +255,7 @@ func (r *Runner) Report(opt Option, report types.Report) error {
 	return nil
 }
 
-func (r *Runner) initDB(c Option) error {
+func (r *runner) initDB(c Option) error {
 	// When scanning config files or running as client mode, it doesn't need to download the vulnerability database.
 	if c.RemoteAddr != "" || !slices.Contains(c.SecurityChecks, types.SecurityCheckVulnerability) {
 		return nil
@@ -230,7 +263,7 @@ func (r *Runner) initDB(c Option) error {
 
 	// download the database file
 	noProgress := c.Quiet || c.NoProgress
-	if err := operation.DownloadDB(c.AppVersion, c.CacheDir, c.DBRepository, noProgress, c.SkipDBUpdate); err != nil {
+	if err := operation.DownloadDB(c.AppVersion, c.CacheDir, c.DBRepository, noProgress, c.Insecure, c.SkipDBUpdate); err != nil {
 		return err
 	}
 
@@ -246,7 +279,7 @@ func (r *Runner) initDB(c Option) error {
 	return nil
 }
 
-func (r *Runner) initCache(c Option) error {
+func (r *runner) initCache(c Option) error {
 	// Skip initializing cache when custom cache is passed
 	if r.cache != nil {
 		return nil
@@ -306,41 +339,41 @@ func run(ctx context.Context, opt Option, artifactType ArtifactType) (err error)
 		}
 	}()
 
-	runner, err := NewRunner(opt)
+	r, err := NewRunner(opt)
 	if err != nil {
 		if errors.Is(err, SkipScan) {
 			return nil
 		}
 		return xerrors.Errorf("init error: %w", err)
 	}
-	defer runner.Close()
+	defer r.Close(ctx)
 
 	var report types.Report
 	switch artifactType {
 	case containerImageArtifact, imageArchiveArtifact:
-		if report, err = runner.ScanImage(ctx, opt); err != nil {
+		if report, err = r.ScanImage(ctx, opt); err != nil {
 			return xerrors.Errorf("image scan error: %w", err)
 		}
 	case filesystemArtifact:
-		if report, err = runner.ScanFilesystem(ctx, opt); err != nil {
+		if report, err = r.ScanFilesystem(ctx, opt); err != nil {
 			return xerrors.Errorf("filesystem scan error: %w", err)
 		}
 	case rootfsArtifact:
-		if report, err = runner.ScanRootfs(ctx, opt); err != nil {
+		if report, err = r.ScanRootfs(ctx, opt); err != nil {
 			return xerrors.Errorf("rootfs scan error: %w", err)
 		}
 	case repositoryArtifact:
-		if report, err = runner.ScanRepository(ctx, opt); err != nil {
+		if report, err = r.ScanRepository(ctx, opt); err != nil {
 			return xerrors.Errorf("repository scan error: %w", err)
 		}
 	}
 
-	report, err = runner.Filter(ctx, opt, report)
+	report, err = r.Filter(ctx, opt, report)
 	if err != nil {
 		return xerrors.Errorf("filter error: %w", err)
 	}
 
-	if err = runner.Report(opt, report); err != nil {
+	if err = r.Report(opt, report); err != nil {
 		return xerrors.Errorf("report error: %w", err)
 	}
 
@@ -400,14 +433,19 @@ func initScannerConfig(opt Option, cacheClient cache.Cache) (ScannerConfig, type
 	scanOptions := types.ScanOptions{
 		VulnType:            opt.VulnType,
 		SecurityChecks:      opt.SecurityChecks,
-		ScanRemovedPackages: opt.ScanRemovedPkgs, // this is valid only for image subcommand
+		ScanRemovedPackages: opt.ScanRemovedPkgs, // this is valid only for 'image' subcommand
 		ListAllPackages:     opt.ListAllPkgs,
 	}
-	log.Logger.Debugf("Vulnerability type:  %s", scanOptions.VulnType)
+
+	if slices.Contains(opt.SecurityChecks, types.SecurityCheckVulnerability) {
+		log.Logger.Info("Vulnerability scanning is enabled")
+		log.Logger.Debugf("Vulnerability type:  %s", scanOptions.VulnType)
+	}
 
 	// ScannerOption is filled only when config scanning is enabled.
 	var configScannerOptions config.ScannerOption
 	if slices.Contains(opt.SecurityChecks, types.SecurityCheckConfig) {
+		log.Logger.Info("Misconfiguration scanning is enabled")
 		configScannerOptions = config.ScannerOption{
 			Trace:        opt.Trace,
 			Namespaces:   append(opt.PolicyNamespaces, defaultPolicyNamespaces...),
@@ -417,6 +455,19 @@ func initScannerConfig(opt Option, cacheClient cache.Cache) (ScannerConfig, type
 		}
 	}
 
+	// Do not load config file for secret scanning
+	if slices.Contains(opt.SecurityChecks, types.SecurityCheckSecret) {
+		ver := fmt.Sprintf("v%s", opt.AppVersion)
+		if opt.AppVersion == "dev" {
+			ver = opt.AppVersion
+		}
+		log.Logger.Info("Secret scanning is enabled")
+		log.Logger.Info("If your scanning is slow, please try '--security-checks vuln' to disable secret scanning")
+		log.Logger.Infof("Please see also https://aquasecurity.github.io/trivy/%s/docs/secret/scanning/#recommendation for faster secret detection", ver)
+	} else {
+		opt.SecretConfigPath = ""
+	}
+
 	return ScannerConfig{
 		Target:             target,
 		ArtifactCache:      cacheClient,
