@@ -3,7 +3,6 @@ package ospkg
 import (
 	"time"
 
-	"github.com/google/wire"
 	"golang.org/x/xerrors"
 
 	fos "github.com/aquasecurity/fanal/analyzer/os"
@@ -27,12 +26,6 @@ var (
 	// ErrUnsupportedOS defines error for unsupported OS
 	ErrUnsupportedOS = xerrors.New("unsupported os")
 
-	// SuperSet binds dependencies for OS scan
-	SuperSet = wire.NewSet(
-		wire.Struct(new(Detector)),
-		wire.Bind(new(Operation), new(Detector)),
-	)
-
 	drivers = map[string]Driver{
 		fos.Alpine:       alpine.NewScanner(),
 		fos.Alma:         alma.NewScanner(),
@@ -55,14 +48,9 @@ func RegisterDriver(name string, driver Driver) {
 	drivers[name] = driver
 }
 
-// Operation defines operation of OSpkg scan
-type Operation interface {
-	Detect(string, string, string, time.Time, []ftypes.Package) ([]types.DetectedVulnerability, bool, error)
-}
-
 // Driver defines operations for OS package scan
 type Driver interface {
-	Detect(string, []ftypes.Package) ([]types.DetectedVulnerability, error)
+	Detect(string, *ftypes.Repository, []ftypes.Package) ([]types.DetectedVulnerability, error)
 	IsSupportedVersion(string, string) bool
 }
 
@@ -70,7 +58,7 @@ type Driver interface {
 type Detector struct{}
 
 // Detect detects the vulnerabilities
-func (d Detector) Detect(_, osFamily, osName string, _ time.Time, pkgs []ftypes.Package) ([]types.DetectedVulnerability, bool, error) {
+func (d Detector) Detect(_, osFamily, osName string, repo *ftypes.Repository, _ time.Time, pkgs []ftypes.Package) ([]types.DetectedVulnerability, bool, error) {
 	driver, err := newDriver(osFamily)
 	if err != nil {
 		return nil, false, ErrUnsupportedOS
@@ -78,7 +66,7 @@ func (d Detector) Detect(_, osFamily, osName string, _ time.Time, pkgs []ftypes.
 
 	eosl := !driver.IsSupportedVersion(osFamily, osName)
 
-	vulns, err := driver.Detect(osName, pkgs)
+	vulns, err := driver.Detect(osName, repo, pkgs)
 	if err != nil {
 		return nil, false, xerrors.Errorf("failed detection: %w", err)
 	}
