@@ -10,6 +10,8 @@ import (
 
 	"github.com/fatih/color"
 	"github.com/liamg/tml"
+	"github.com/samber/lo"
+	"github.com/xlab/treeprint"
 	"golang.org/x/exp/slices"
 
 	ftypes "github.com/aquasecurity/fanal/types"
@@ -34,6 +36,9 @@ type TableWriter struct {
 	Severities []dbTypes.Severity
 	Output     io.Writer
 
+	// Show dependency origin tree
+	Tree bool
+
 	// We have to show a message once about using the '-format json' subcommand to get the full pkgPath
 	ShowMessageOnce *sync.Once
 
@@ -45,6 +50,10 @@ type TableWriter struct {
 // Write writes the result on standard output
 func (tw TableWriter) Write(report types.Report) error {
 	for _, result := range report.Results {
+		// Not display a table of custom resources
+		if result.Class == types.ClassCustom {
+			continue
+		}
 		tw.write(result)
 	}
 	return nil
@@ -62,7 +71,6 @@ func (tw TableWriter) isOutputToTerminal() bool {
 }
 
 func (tw TableWriter) write(result types.Result) {
-
 	tableWriter := table.New(tw.Output)
 	if tw.isOutputToTerminal() { // use ansi output if we're not piping elsewhere
 		tableWriter.SetHeaderStyle(table.StyleBold)
@@ -84,7 +92,9 @@ func (tw TableWriter) write(result types.Result) {
 	total, summaries := tw.summary(severityCount)
 
 	target := result.Target
-	if result.Class == types.ClassSecret {
+	if result.Class == types.ClassConfig && len(result.Misconfigurations) == 0 {
+		return
+	} else if result.Class == types.ClassSecret {
 		if len(result.Secrets) == 0 {
 			return
 		}
@@ -117,6 +127,10 @@ func (tw TableWriter) write(result types.Result) {
 		_, _ = fmt.Fprint(tw.Output, NewMisconfigRenderer(result.Target, result.Misconfigurations, tw.IncludeNonFailures, tw.isOutputToTerminal()).Render())
 	}
 
+	if tw.Tree {
+		tw.renderDependencyTree(result)
+	}
+
 	// For debugging
 	if tw.Trace {
 		tw.outputTrace(result)
@@ -191,6 +205,81 @@ func (tw TableWriter) setVulnerabilityRows(tableWriter *table.Table, vulns []typ
 		tableWriter.AddRow(row...)
 	}
 }
+func (tw TableWriter) renderDependencyTree(result types.Result) {
+	// Get parents of each dependency
+	parents := reverseDeps(result.Packages)
+	if len(parents) == 0 {
+		return
+	}
+
+	root := treeprint.NewWithRoot(fmt.Sprintf(`
+Dependency Origin Tree
+======================
+%s`, result.Target))
+
+	// This count is next to the package ID.
+	// e.g. node-fetch@1.7.3 (MEDIUM: 2, HIGH: 1, CRITICAL: 3)
+	pkgSeverityCount := map[string]map[string]int{}
+	for _, vuln := range result.Vulnerabilities {
+		cnts, ok := pkgSeverityCount[vuln.PkgID]
+		if !ok {
+			cnts = map[string]int{}
+		}
+
+		cnts[vuln.Severity]++
+		pkgSeverityCount[vuln.PkgID] = cnts
+	}
+
+	// Render tree
+	seen := map[string]struct{}{}
+	for _, vuln := range result.Vulnerabilities {
+		if _, ok := seen[vuln.PkgID]; ok {
+			continue
+		}
+
+		_, summaries := tw.summary(pkgSeverityCount[vuln.PkgID])
+		topLvlID := fmt.Sprintf("%s, (%s)", vuln.PkgID, strings.Join(summaries, ", "))
+		if tw.isOutputToTerminal() {
+			topLvlID = color.HiRedString(topLvlID)
+		}
+
+		seen[vuln.PkgID] = struct{}{}
+		branch := root.AddBranch(topLvlID)
+		addParents(branch, vuln.PkgID, parents)
+
+	}
+	tw.Println(root.String())
+}
+
+func addParents(topItem treeprint.Tree, pkgID string, parentMap map[string][]string) {
+	parents, ok := parentMap[pkgID]
+	if !ok {
+		return
+	}
+	for _, parent := range parents {
+		branch := topItem.AddBranch(parent)
+		addParents(branch, parent, parentMap)
+	}
+}
+
+func reverseDeps(libs []ftypes.Package) map[string][]string {
+	reversed := make(map[string][]string)
+	for _, lib := range libs {
+		for _, dependOn := range lib.DependsOn {
+			items, ok := reversed[dependOn]
+			if !ok {
+				reversed[dependOn] = []string{lib.ID}
+			} else {
+				reversed[dependOn] = append(items, lib.ID)
+			}
+		}
+	}
+
+	for k, v := range reversed {
+		reversed[k] = lo.Uniq(v)
+	}
+	return reversed
+}
 
 func (tw TableWriter) outputTrace(result types.Result) {
 	blue := color.New(color.FgBlue).SprintFunc()
